@@ -1,6 +1,6 @@
 /* constants defined for LDAP
  * See http://www.python-ldap.org/ for details.
- * $Id: constants.c,v 1.35 2009/04/17 12:19:09 stroeder Exp $ */
+ * $Id: constants.c,v 1.36 2009/05/04 10:07:52 stroeder Exp $ */
 
 #include "common.h"
 #include "constants.h"
@@ -190,6 +190,9 @@ LDAPinit_constants( PyObject* d )
 	add_int(d,OPT_X_SASL_SECPROPS);
 	add_int(d,OPT_X_SASL_SSF_MIN);
 	add_int(d,OPT_X_SASL_SSF_MAX);
+#ifdef LDAP_OPT_X_SASL_NOCANON
+	add_int(d,OPT_X_SASL_NOCANON);
+#endif
 
 	add_int(d,DN_FORMAT_LDAP);
 	add_int(d,DN_FORMAT_LDAPV3);
